FitType class

Constructors

FitType(bool endianAbility, int baseTypeField, String typeName, Object invalidValue, int size, bool isSigned, bool isInteger)

Properties

baseTypeField int
final
endianAbility bool
final
hashCode int
The hash code for this object.
no setterinherited
invalidValue Object
final
isInteger bool
final
isSigned bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
typeName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited