MesgDefinition class
- Available extensions
Constructors
Properties
-
developerFieldDefinitions
→ List<
DeveloperFieldDefinition> -
no setter
- globalMesgNum ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBigEndian ↔ bool
-
getter/setter pair
- localMesgNum ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDeveloperField(
DeveloperFieldDefinition field) → void -
addField(
FieldDefinition field) → void -
getFields(
) → List< FieldDefinition> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
EndianBinaryReader reader, {DeveloperDataLookup? lookup}) → void -
supports(
Mesg mesg) → bool -
Available on MesgDefinition, provided by the MesgDefinitionSupports extension
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
EndianBinaryWriter writer) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited