SubfieldMap class

Constructors

SubfieldMap(int refFieldNum, Object refFieldValue)
SubfieldMap.fromOther(SubfieldMap other)

Properties

hashCode int
The hash code for this object.
no setterinherited
refFieldNum int
getter/setter pair
refFieldValue Object
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canMesgSupport(Mesg mesg) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited