AccumulatedField class
Constructors
- AccumulatedField(int mesgNum, int destFieldNum)
Properties
- accumulatedValue ↔ int
-
getter/setter pair
- destFieldNum → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastValue ↔ int
-
getter/setter pair
- mesgNum → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accumulate(
int value, int bits) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
int value) → int -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited