EndianBinaryWriter class
Constructors
- EndianBinaryWriter([bool isBigEndian = false])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBigEndian ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
contents(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
-
writeByte(
int value) → void -
writeBytes(
Uint8List value) → void -
writeFloat32(
double value) → void -
writeFloat64(
double value) → void -
writeInt16(
int value) → void -
writeInt32(
int value) → void -
writeSByte(
int value) → void -
writeSInt64(
int value) → void -
writeUInt16(
int value) → void -
writeUInt32(
int value) → void -
writeUInt64(
int value) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited